@@ -67,6 +67,18 @@ $example->Annotate(text=>'Magick',geometry=>'+0+20',font=>'Generic.ttf',
   fill=>'gold',gravity=>'North',pointsize=>14);
 push(@$images,$example);
 
+print "Auto-gamma...\n";
+$example=$model->Clone();
+$example->Label('Auto Gamma');
+$example->AutoGamma();
+push(@$images,$example);
+
+print "Auto-level...\n";
+$example=$model->Clone();
+$example->Label('Auto Level');
+$example->AutoLevel();
+push(@$images,$example);
+
 print "Blur...\n";
 $example=$model->Clone();
 $example->Label('Blur');
@@ -91,6 +103,12 @@ $example->Label('Charcoal');
 $example->Charcoal('0x1');
 push(@$images,$example);
 
+print "ColorMatrix...\n";
+$example=$model->Clone();
+$example->Label('ColorMatrix');
+$example->ColorMatrix([1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0.5, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1]);
+push(@$images,$example);
+
 print "Composite...\n";
 $example=$model->Clone();
 $example->Label('Composite');
@@ -107,8 +125,8 @@ print "Contrast Stretch...\n";
 $example=$model->Clone();
 $example->Label('Contrast Stretch');
 $example->ContrastStretch('5%');
-
 push(@$images,$example);
+
 print "Convolve...\n";
 $example=$model->Clone();
 $example->Label('Convolve');
@@ -131,7 +149,7 @@ push(@$images,$example);
 print "Distort...\n";
 $example=$model->Clone();
 $example->Label('Distort');
-$example->Distort(type=>'arc',points=>[120],'virtual-pixel'=>'white');
+$example->Distort(method=>'arc',points=>[60],'virtual-pixel'=>'white');
 push(@$images,$example);
 
 print "Draw...\n";
@@ -211,7 +229,7 @@ push(@$images,$gradient);
 print "Grayscale...\n";
 $example=$model->Clone();
 $example->Label('Grayscale');
-$example->Quantize(colorspace=>'gray');
+$example->Set(type=>'grayscale');
 push(@$images,$example);
 
 print "Implode...\n";
@@ -232,6 +250,12 @@ $example->Label('Median Filter');
 $example->MedianFilter();
 push(@$images,$example);
 
+print "Mode...\n";
+$example=$model->Clone();
+$example->Label('Mode');
+$example->Mode();
+push(@$images,$example);
+
 print "Modulate...\n";
 $example=$model->Clone();
 $example->Label('Modulate');
@@ -240,10 +264,17 @@ push(@$images,$example);
 $example=$model->Clone();
 
 print "Monochrome...\n";
+$example=$model->Clone();
 $example->Label('Monochrome');
 $example->Quantize(colorspace=>'gray',colors=>2,dither=>'false');
 push(@$images,$example);
 
+print "Morphology...\n";
+$example=$model->Clone();
+$example->Label('Morphology');
+$example->Morphology(method=>'Dilate',kernel=>'Diamond',iterations=>2);
+push(@$images,$example);
+
 print "Motion Blur...\n";
 $example=$model->Clone();
 $example->Label('Motion Blur');
@@ -279,7 +310,13 @@ push(@$images,$plasma);
 print "Polaroid...\n";
 $example=$model->Clone();
 $example->Label('Polaroid');
-$example->Polaroid(caption=>'Magick',rotate=>-5.0,gravity=>'center');
+$example->Polaroid(caption=>'Magick',angle=>-5.0,gravity=>'center');
+push(@$images,$example);
+
+print "Posterize...\n";
+$example=$model->Clone();
+$example->Label('Posterize');
+$example->Posterize(5);
 push(@$images,$example);
 
 print "Quantize...\n";
@@ -300,13 +337,6 @@ $example->Label('Raise');
 $example->Raise('10x10');
 push(@$images,$example);
 
-push(@$images,$example);
-print "Recolor...\n";
-$example=$model->Clone();
-$example->Label('Recolor');
-$example->Recolor([1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0.5, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1]);
-push(@$images,$example);
-
 print "Reduce Noise...\n";
 $example=$model->Clone();
 $example->Label('Reduce Noise');
@@ -373,6 +403,13 @@ $example->Label('Shear');
 $example->Shear('-20x20');
 push(@$images,$example);
 
+print "Sketch...\n";
+$example=$model->Clone();
+$example->Label('Sketch');
+$example->Set(colorspace=>'Gray');
+$example->Sketch('0x20+120');
+push(@$images,$example);
+
 print "Sigmoidal Contrast...\n";
 $example=$model->Clone();
 $example->Label('Sigmoidal Contrast');
@@ -421,7 +458,7 @@ print "Montage...\n";
 $montage=$images->Montage(geometry=>'128x160+8+4>',gravity=>'Center',
   tile=>'5x+10+200',compose=>'over',background=>'#ffffff',
   font=>'Generic.ttf',pointsize=>18,fill=>'#600',stroke=>'none',
-	shadow=>'true');
+  shadow=>'true');
 
 $logo=Image::Magick->new();
 $logo->Read('logo:');
